# create_textgrid_mfa_timestamps2.praat
# Written by E. Chodroff
# Oct 11 2019

# This script takes as input a series of text files, each with a corresponding wav file
# The text files and wav files are in the same directory and have the exact same name
# The text file has TWO columns and is tab-delimited
# The first column has the start time of the utterance
# The second column has the utterance
# Assumes that the end of an utterance is ~10 ms before the start of the next utterance
# This assumption can be changed with the sepInt (separate intervals) parameter in the CHANGE ME! section


### CHANGE ME!
dir$ = "/Users/eleanorchodroff/Desktop/input/"
sepInt = 0.01
###

Create Strings as file list: "files", dir$ + "*.txt"
nFiles = Get number of strings

for i from 1 to nFiles
	selectObject: "Strings files"
	filename$ = Get string: i
	basename$ = filename$ - ".txt"
	
	# read in transcript
	Read Table from tab-separated file: dir$ + basename$ + ".txt"
	nRows = Get number of rows

	# get names of columns
	startCol$ = Get column label: 1
	uttCol$ = Get column label: 2

	# read in wav
	Read from file: dir$ + basename$ + ".wav"
	dur = Get total duration

	# create TextGrid
	To TextGrid: "utt", ""

	# add in boundaries and text
	for j from 1 to nRows
		selectObject: "Table " + basename$
		if j < nRows
			start = Get value: j, startCol$
			end = Get value: j+1, startCol$
			end = end - sepInt
		else
			start = Get value: j, startCol$
			end = dur - sepInt
		endif

		# insert utterance text
		utt$ = Get value: j, uttCol$
		selectObject: "TextGrid " + basename$
		Insert boundary: 1, start
		Insert boundary: 1, end
		labelInt = Get interval at time: 1, end-0.0015
		Set interval text: 1, labelInt, utt$
	endfor

	# save textgrid
	selectObject: "TextGrid " + basename$
	Save as text file: dir$ + basename$ + ".TextGrid"
	
	# clean up
	select all
	minusObject: "Strings files"
	Remove
endfor

